@@ -76,11 +76,17 @@ class RootDiskSelectionHook(base.ProcessingHook):
         root_disk = introspection_data.get('root_disk')
         if root_disk:
             local_gb = root_disk['size'] // units.Gi
-            if CONF.processing.disk_partitioning_spacing:
-                local_gb -= 1
-            LOG.info('Root disk %(disk)s, local_gb %(local_gb)s GiB',
-                     {'disk': root_disk, 'local_gb': local_gb},
-                     node_info=node_info, data=introspection_data)
+            if not local_gb:
+                LOG.warning('The requested root disk is too small (smaller '
+                            'than 1 GiB) or its size cannot be detected: %s',
+                            root_disk,
+                            node_info=node_info, data=introspection_data)
+            else:
+                if CONF.processing.disk_partitioning_spacing:
+                    local_gb -= 1
+                LOG.info('Root disk %(disk)s, local_gb %(local_gb)s GiB',
+                         {'disk': root_disk, 'local_gb': local_gb},
+                         node_info=node_info, data=introspection_data)
         else:
             local_gb = 0
             LOG.info('No root device found, assuming a diskless node',
@@ -220,8 +226,7 @@ class ValidateInterfacesHook(base.ProcessingHook):
                 LOG.debug('Skipping interface %s as it was not PXE booting',
                           name, data=data)
                 continue
-            elif CONF.processing.add_ports != 'all' and (
-                        not ip or netaddr.IPAddress(ip).is_link_local()):
+            elif CONF.processing.add_ports != 'all' and not ip:
                 LOG.debug('Skipping interface %s as it did not have '
                           'an IP address assigned during the ramdisk run',
                           name, data=data)
@@ -296,7 +301,7 @@ class ValidateInterfacesHook(base.ProcessingHook):
                     node_info.delete_port(port)
 
         if CONF.processing.overwrite_existing:
-            # Make sure pxe_enabled is up-to-date
+            # Make sure is_pxe_enabled is up-to-date
             ports = node_info.ports()
             for iface in introspection_data['interfaces'].values():
                 try:
@@ -305,8 +310,8 @@ class ValidateInterfacesHook(base.ProcessingHook):
                     continue
 
                 real_pxe = iface.get('pxe', True)
-                if port.pxe_enabled != real_pxe:
-                    LOG.info('Fixing pxe_enabled=%(val)s on port %(port)s '
+                if port.is_pxe_enabled != real_pxe:
+                    LOG.info('Fixing is_pxe_enabled=%(val)s on port %(port)s '
                              'to match introspected data',
                              {'port': port.address, 'val': real_pxe},
                              node_info=node_info, data=introspection_data)
